@@ -8,9 +8,9 @@ use serde::{Serialize, Deserialize};
 /// ```
 /// use bgpkit_broker::QueryParams;
 /// let mut params = QueryParams::new();
-/// params = params.start_ts(1633046400);
-/// params = params.end_ts(1633132800);
-/// params = params.collector("rrc00");
+/// params = params.ts_start("1633046400");
+/// params = params.ts_end("1633132800");
+/// params = params.collector_id("rrc00");
 /// params = params.project("riperis");
 /// params = params.data_type("rib");
 /// params = params.page(2);
@@ -26,18 +26,16 @@ use serde::{Serialize, Deserialize};
 /// - each page contains 20 items
 #[derive(Debug, Serialize, Deserialize, Clone)]
 pub struct QueryParams {
-    /// start unix timestamp: files with time after or equals to `start_ts` will match
-    pub start_ts: Option<i64>,
-    /// end unix timestamp: files with time before or equals to `end_ts` will match
-    pub end_ts: Option<i64>,
+    /// start unix timestamp: files with time after or equals to `ts_start` will match
+    pub ts_start: Option<String>,
+    /// end unix timestamp: files with time before or equals to `ts_end` will match
+    pub ts_end: Option<String>,
     /// collector identifier, e.g. `rrc00` or `route-views2`
-    pub collector: Option<String>,
+    pub collector_id: Option<String>,
     /// archive project name: `riperis` or `routeviews`
     pub project: Option<String>,
     /// archive data type: `rib` or `update`
     pub data_type: Option<String>,
-    /// sort order by time: `desc` or `asc`, see [SortOrder]
-    pub order: SortOrder,
     /// page number to seek to, starting from 1, default to 1
     pub page: i64,
     /// number of items each page contains, default to 10, max to 100000
@@ -57,14 +55,13 @@ pub enum SortOrder {
 impl Default for QueryParams {
     fn default() -> Self {
         QueryParams{
-            start_ts: None,
-            end_ts: None,
-            collector: None,
+            ts_start: None,
+            ts_end: None,
+            collector_id: None,
             project: None,
             data_type: None,
-            order: SortOrder::ASC,
             page: 1,
-            page_size: 10
+            page_size: 100
         }
     }
 }
@@ -81,13 +78,13 @@ impl Display for SortOrder {
 impl std::fmt::Display for QueryParams {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         let mut params_vec = vec![];
-        if let Some(v) = &self.start_ts {
-            params_vec.push(format!("start_ts={}", v));
+        if let Some(v) = &self.ts_start {
+            params_vec.push(format!("ts_start={}", v));
         }
-        if let Some(v) = &self.end_ts {
-            params_vec.push(format!("end_ts={}", v));
+        if let Some(v) = &self.ts_end {
+            params_vec.push(format!("ts_end={}", v));
         }
-        if let Some(v) = &self.collector {
+        if let Some(v) = &self.collector_id {
             params_vec.push(format!("collector={}", v));
         }
         if let Some(v) = &self.project {
@@ -96,7 +93,6 @@ impl std::fmt::Display for QueryParams {
         if let Some(v) = &self.data_type {
             params_vec.push(format!("data_type={}", v));
         }
-        params_vec.push(format!("order={}", self.order));
         params_vec.push(format!("page={}", self.page));
         params_vec.push(format!("page_size={}", self.page_size));
 
@@ -111,12 +107,11 @@ impl std::fmt::Display for QueryParams {
 impl QueryParams {
     pub fn new() -> QueryParams {
         QueryParams{
-            start_ts: None,
-            end_ts: None,
-            collector: None,
+            ts_start: None,
+            ts_end: None,
+            collector_id: None,
             project: None,
             data_type: None,
-            order: SortOrder::ASC,
             page: 1,
             page_size: 10
         }
@@ -127,10 +122,10 @@ impl QueryParams {
     /// ```
     /// use bgpkit_broker::QueryParams;
     /// let mut params = QueryParams::new();
-    /// params = params.start_ts(1633046400);
+    /// params = params.ts_start("1633046400");
     /// ```
-    pub fn start_ts(self, start_ts:i64) -> Self {
-        QueryParams{ start_ts: Some(start_ts), ..self}
+    pub fn ts_start(self, ts_start:&str) -> Self {
+        QueryParams{ ts_start: Some(ts_start.to_string()), ..self}
     }
 
     /// set ending timestamp for the search and returns a new [QueryParams] object.
@@ -138,10 +133,10 @@ impl QueryParams {
     /// ```
     /// use bgpkit_broker::QueryParams;
     /// let mut params = QueryParams::new();
-    /// params = params.end_ts(1633046400);
+    /// params = params.ts_end("1633046400");
     /// ```
-    pub fn end_ts(self, end_ts:i64) -> Self {
-        QueryParams{ end_ts: Some(end_ts), ..self}
+    pub fn ts_end(self, ts_end: &str) -> Self {
+        QueryParams{ ts_end: Some(ts_end.to_string()), ..self}
     }
 
     /// set page number for the each for pagination. **the page number starts from 1**.
@@ -166,19 +161,6 @@ impl QueryParams {
         QueryParams{ page_size, ..self}
     }
 
-    /// set return objects ordering in terms of timestamps:
-    /// - `asc` for timestamps increasing order (default)
-    /// - `desc` for timestamps decreasing order
-    ///
-    /// ```
-    /// use bgpkit_broker::{QueryParams, SortOrder};
-    /// let mut params = QueryParams::new();
-    /// params = params.order(SortOrder::DESC);
-    /// ```
-    pub fn order(self, order:SortOrder) -> Self {
-        QueryParams{ order, ..self}
-    }
-
     /// set the type of data to search for:
     /// - `rib`: table dump files
     /// - `update`: BGP updates files
@@ -212,87 +194,84 @@ impl QueryParams {
     /// ```
     /// use bgpkit_broker::QueryParams;
     /// let mut params = QueryParams::new();
-    /// params = params.collector("rrc00");
+    /// params = params.collector_id("rrc00");
     /// ```
-    pub fn collector(self, collector:&str) -> Self {
-        QueryParams{ collector: Some(collector.to_string()), ..self}
+    pub fn collector_id(self, collector_id:&str) -> Self {
+        QueryParams{ collector_id: Some(collector_id.to_string()), ..self}
     }
 }
 
 /// BGPKIT Broker data item.
 ///
 /// The fields are:
+/// - [ts_start][BrokerItem::ts_start]: the starting timestamp of the data file
+/// - [ts_end][BrokerItem::ts_end]: the ending timestamp of the data file
 /// - [collector_id][BrokerItem::collector_id]: the collector id of the item: e.g. `rrc00`
-/// - [timestamp][BrokerItem::timestamp]: the unitimestamp timestamp of the data file
 /// - [data_type][BrokerItem::data_type]: type of the data item: `rib` or `update`
 /// - [url][BrokerItem::url]: the URL to the data item file
+/// - [rough_size][BrokerItem::rough_size]: rough file size extracted from the collector webpage
+/// - [exact_size][BrokerItem::exact_size]: exact file size extracted by crawling the file
 #[derive(Debug, Serialize, Deserialize)]
 pub struct BrokerItem {
+    /// start timestamp
+    pub ts_start: chrono::NaiveDateTime,
+    /// end timestamps
+    pub ts_end: chrono::NaiveDateTime,
     /// the collector id of the item: e.g. `rrc00`
     pub collector_id: String,
-    /// the unix timestamp of the data file
-    pub timestamp: i64,
     /// type of the data item: `rib` or `update`
     pub data_type: String,
     /// the URL to the data item file
     pub url: String,
-}
-
-/// a wrapper struct of the returning values that include some meta information.
-#[derive(Debug, Serialize, Deserialize)]
-pub(crate) struct DataWrapper {
-    /// the returning data [Item]s
-    pub items: Vec<BrokerItem>,
-    /// number of items returned in **current** call
-    pub count: i64,
-    /// the page number of the current call
-    pub current_page: i64,
-    /// the number of items per page
-    pub page_size: i64,
-    /// total number of pages
-    pub total_pages: i64,
+    /// rough file size extracted from the hosting site page
+    pub rough_size: i64,
+    /// exact file size extracted by crawling the file
+    pub exact_size: i64,
 }
 
 /// Query result struct that contains data or error message
 #[derive(Debug, Serialize, Deserialize)]
 pub(crate) struct QueryResult {
-    /// Option that contains [DataWrapper] if the search call is successful
-    pub data: Option<DataWrapper>,
-    /// Option that contains an error message if the search call failed
-    pub error: Option<String>
+    /// number of items returned in **current** call
+    pub count: Option<i64>,
+    /// the page number of the current call
+    pub page: Option<i64>,
+    /// the number of items per page
+    pub page_size: Option<i64>,
+    /// Error message
+    pub error: Option<String>,
+    /// the returning data [Item]s
+    pub data: Vec<BrokerItem>,
 }
 
 #[cfg(test)]
 mod tests {
-    use crate::SortOrder::ASC;
     use super::*;
 
     #[test]
     fn test_param_to_string() {
         let param = QueryParams{
-            start_ts: Some(1),
-            end_ts: Some(2),
-            collector: None,
+            ts_start: Some("1".to_string()),
+            ts_end: Some("2".to_string()),
+            collector_id: None,
             project: Some("test_project".to_string()),
             data_type: None,
-            order: ASC,
             page: 1,
             page_size: 20
         };
 
-        assert_eq!("?start_ts=1&end_ts=2&project=test_project&order=asc&page=1&page_size=20".to_string(), param.to_string());
+        assert_eq!("?ts_start=1&ts_end=2&project=test_project&page=1&page_size=20".to_string(), param.to_string());
 
         let param = QueryParams{
-            start_ts: None,
-            end_ts: None,
-            collector: None,
+            ts_start: None,
+            ts_end: None,
+            collector_id: None,
             project: None,
             data_type: None,
-            order: ASC,
             page: 1,
             page_size: 20
         };
 
-        assert_eq!("?order=asc&page=1&page_size=20".to_string(), param.to_string());
+        assert_eq!("?page=1&page_size=20".to_string(), param.to_string());
     }
 }
\ No newline at end of file
